DynamicLibrary class

Represents a dynamically loaded C library.

Available extensions

Constructors

DynamicLibrary.fromModule(Module module, [MemoryRegisterMode registerMode = MemoryRegisterMode.onlyIfGlobalNotSet])
Creates a new instance based on the given module.
factory

Properties

boundMemory → Memory
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lookup<T extends NativeType>(String name) → Pointer<T>
Looks up a symbol in the DynamicLibrary and returns its address in memory.
lookupFunction<T extends Function, F extends Function>(String name) → F

Available on DynamicLibrary, provided by the DynamicLibraryExtension extension

Helper that combines lookup and cast to a Dart function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited